


# Ceridian Connector

## About Ceridian:

Cloud HCM software that brings together real-time payroll, HR, benefits, time reporting, talent and workforce management to empower your people.

## Connector features:

-   **Pull jobs** The connector retrieves job information from the Ceridian website using the Ceridian API and indexes it to an HrFlow Board.

## Useful links:

📄Visit [Ceridian](https://www.workable.com/) to learn more.

💻 [Connector code]([https://github.com/Sprenger07/hrflow-connectors/tree/feature/update-connector-workable/src/hrflow_connectors/connectors/workable](https://github.com/Sprenger07/hrflow-connectors/tree/feature/update-connector-workable/src/hrflow_connectors/connectors/workable)) on our Github.
